<!-- template:docs -->

## What does this PR change?

Brief description of the documentation or CI/tooling change.

## Type of change

- [ ] Documentation (README, CONTRIBUTING, code comments)
- [ ] CI / GitHub Actions
- [ ] Pre-commit hooks / tooling
- [ ] Other chore

## Checklist

- [ ] `pytest tests/ -v` passes (if applicable)
- [ ] `smellcheck src/smellcheck/` self-check runs clean (if applicable)
- [ ] Commit messages follow [Conventional Commits](https://www.conventionalcommits.org/)

## Additional context

Any other context.
